This function returns a function that computes residuals for envelope plots. These residuals are typically absolute values to be compared against the half-normal distribution.
envelope_residual(object, ...)# S3 method for default
envelope_residual(object, ...)
# S3 method for glm
envelope_residual(object, ...)
# S3 method for lm
envelope_residual(object, ...)
A function that computes residuals from an object
An object for which model residuals can be extracted.
Additional arguments passed to the residual function.
For objects of class glm, the default residuals are:
Deviance residuals, except for poisson and binomial families.
For poisson and binomial families it uses deletion residual adapted from rstudent().
For objects of class lm, the default residuals is rstudent().
For other classes, the default is stats::residuals(), meaning no specialized recommendation is currently provided.